set varabbrev off
cap postclose myhandle
set more off


postfile myhandle str10 gender nserve serve N D p Npointreject05 Npointreject10 using "Results/KSexactHK", replace
forvalues i=1/2{ /*first or second serve*/
	foreach gender in "male" "female"{
		di "`gender'"
		foreach nserve in 10{ /*resctriction to pointgames with at least 10 serves (see Appendix A data cleaning)*/
			di `nserve'
			use "./data/pointgames.dta", clear
			keep if totalserves1>=`nserve' & gender=="`gender'" 
			cap drop pointwon`i'
			gen pointwon`i'=pointwonL`i'+pointwonR`i'
			cap drop pointlost`i'
			gen pointlost`i'=totalserves`i'-pointwon`i'
			gen A=pointwonL`i'
			gen e=pointwon`i'
			gen f=pointlost`i'
			gen g=servesL`i'
			gen h=servesR`i'
			gen b=0
			cap drop c
			gen c=0
			gen d=0
			gen a=0
			egen maxpointwon`i'=max(pointwon`i')
			local maxpointwon=maxpointwon`i'
			cap drop Fexact
			gen double  Fexact=0
			cap drop Fminus1exact
			gen double  Fminus1exact=0
			cap drop Ftotexact
			gen double  Ftotexact=0
			local maxpointwon=maxpointwon`i'
			cap drop fi
			gen double fi=0
			forvalues a=0/`maxpointwon'{
				replace fi=0
				replace a=`a'
				replace b=e-a if a<=g & h-e+a>=0
				replace c=g-a if a<=g & h-e+a>=0
				replace d=h-b if a<=g & h-e+a>=0
				replace fi= round(exp(lnfactorial(e)),1)*round(exp(lnfactorial(f)),1)*round(exp(lnfactorial(g)),1)*round(exp(lnfactorial(h)),1) ///
					/(round(exp(lnfactorial(a)),1)*round(exp(lnfactorial(b)),1)*round(exp(lnfactorial(c)),1)*round(exp(lnfactorial(d)),1)*round(exp(lnfactorial(a+b+c+d)),1)) if a<=g & h-e+a>=0 
					replace Ftotexact=Ftotexact+fi if a<=g & h-e+a>=0 & fi!=.
					replace Fminus1exact=Fminus1exact+fi if a<=g & h-e+a>=0 & A>a & fi!=.
					replace Fexact=Fexact+fi if a<=g & h-e+a>=0 & A>=a & fi!=.
				}
			forval j=1/10000{ /*number iteration at a specific winrate*/
				if mod(`j',10)==0	{	
					di `j'
				}
				cap{			
					cap drop texact
					gen texact=Fminus1exact+(Fexact-Fminus1exact)*runiform()
					count if texact<=0.025 | texact>=0.975
					local Npointreject05=r(N)
					count if texact<=0.05 | texact>=0.95
					local Npointreject10=r(N)
					cap drop c
					cumul texact, gen(c)
					sort c
					ksmirnov texact=texact 
					local KS=sqrt(_N)*r(D)			
				}
				post myhandle  ("`gender'") (`nserve') (`i') (_N) (r(D)) (r(p)) (`Npointreject05') (`Npointreject10')
			}
		}
	}
}
postclose myhandle

use "Results/KSexactHK.dta", clear 

gen pointreject05=Npointreject05/N*100
gen pointreject10=Npointreject10/N*100

*This is Table 3, change serve and gender approprietly*/
sum pointreject05 pointreject10 if serve==2 & gender=="male" 

sort gender nserve serve
gen id=_n
by  gender nserve serve: egen pmean=mean(p)
cap drop reject10
gen reject5=0 
replace reject5=1 if p<0.05
cap drop preject5
by  gender nserve serve: egen preject5=mean(reject5)
cap drop reject
by  gender nserve serve: gen reject10=0 
 replace reject10=1 if p<0.1
cap drop preject10
by  gender nserve serve: egen preject10=mean(reject10)

by  gender nserve serve: gen first=1 if _n==1

ed gender nserve serve preject5 preject10 if first==1

forvalues serve=1/2{
	foreach gender in "male" "female"{
		local name="histp"+"`gender'"+"`serve'"
		sum p if gender=="`gender'" & nserve==10 & serve==`serve'
		local min:di%4.3f r(min)
		local max:di%4.3f r(max)
		local mean:di%4.3f r(mean)
		if `max'==1{
				local max:di%1.0f `max'
				}
		if `min'==0{
				local min:di %1.0f `min'
		}
		local line1="min="+"`min'"
		local line2="max="+"`max'"
		local line3="mean="+"`mean'"
		local  Npoint=r(N)
		count if p<=0.05 & gender=="`gender'" & nserve==10 & serve==`serve'
		local preject5=r(N)/`Npoint'*100
		local preject5:di%4.2f `preject5'
		count if p<=0.1 & gender=="`gender'" & nserve==10 & serve==`serve'
		local preject10=r(N)/`Npoint'*100
		local preject10:di%4.2f `preject10'
		local line1="min="+"`min'"
		local line2="max="+"`max'"
		local line3="mean="+"`mean'"
		local line4="% rejected at 5%="+"`preject5'"+" %"
		local line5="% rejected at 10%="+"`preject10'"+" %"
		
		count if gender=="`gender'" & nserve==10 & serve==`serve'
		local N:di%5.0fc r(N)
		local line6="# iteration="+"`N'"
					
		local x=0.28
		if "`gender'"=="male" & `serve'==1{
			local y=2.25
			local x=0.28
			local maxy=3
		}
		if "`gender'"=="male" & `serve'==2{
			local y=1.5
			local maxy=2
		}
		if "`gender'"=="female" & `serve'==1{
			local y=7.5
			local maxy=10.2
		}
		
		if "`gender'"=="female" & `serve'==2{
			local y=3
			local maxy=4
		}
			
		local namegraph="Figure\"+"`name'"+"color.png"
		tw (hist p if gender=="`gender'" & nserve==10 & serve==`serve', w(0.01) name("`name'",replace)  ////
			 ytitle("Density", size(5))  xlabel(0 0.05 0.1 1) graphregion(color(white)) legend(off) plotr(margin(zero))   ///
			text(`y' `x' "`line1'" "`line2'" "`line3'" "`line4'" "`line5'", ////
			size(5) box  justification(left) bmargin(vlarge)  bcolor(white) width(40) height(15)   placement(12) ) )  ///
			(scatteri 0 0.05 `maxy' 0.05, lw(thin)  c(l) m(i) lcolor(black)  ) ///
			(scatteri 0 0.1 `maxy' 0.1, lw(thin)  c(l) m(i) lcolor(black) )
			graph export "`namegraph'" , wid(1200) hei(900)  as(png) replace
		}
	}
