set varabbrev off
cap postclose myhandle
set more off

postfile myhandle N Dexact pexact Npointreject05 Npointreject10 using "Results/KSexactOneil", replace
	use "./data/Oneildata.dta", clear
		
	cap drop pointwon
	gen pointwon=pointwonL+pointwonR
	cap drop pointlost
	gen pointlost=totalserves-pointwon
	gen A=pointwonL
	gen e=pointwon
	gen f=pointlost
	gen g=servesL
	gen h=servesR
	gen b=0
	cap drop c
	gen c=0
	gen d=0
	gen a=0
	egen maxpointwon=max(pointwon)
	local maxpointwon=maxpointwon

	forval j=1/10000{ /*number iteration at a specific winrate*/
		if mod(`j',100)==0	{	
			di `j'
		}
		cap{
			cap drop Fexact
			gen double  Fexact=0
			cap drop Fminus1exact
			gen double  Fminus1exact=0
			cap drop Ftotexact
			gen double  Ftotexact=0
			local maxpointwon=maxpointwon
			cap drop fi
			gen double fi=0

			forvalues a=0/`maxpointwon'{
				replace fi=0
				replace a=`a'
				replace b=e-a if a<=g & h-e+a>=0
				replace c=g-a if a<=g & h-e+a>=0
				replace d=h-b if a<=g & h-e+a>=0
				*local tab="`a'"+","+"`b'"+"/"+"`c'"+","+"`d'"
				replace fi= round(exp(lnfactorial(e)),1)*round(exp(lnfactorial(f)),1)*round(exp(lnfactorial(g)),1)*round(exp(lnfactorial(h)),1) ///
					/(round(exp(lnfactorial(a)),1)*round(exp(lnfactorial(b)),1)*round(exp(lnfactorial(c)),1)*round(exp(lnfactorial(d)),1)*round(exp(lnfactorial(a+b+c+d)),1)) if a<=g & h-e+a>=0 
					replace Ftotexact=Ftotexact+fi if a<=g & h-e+a>=0 & fi!=.
					replace Fminus1exact=Fminus1exact+fi if a<=g & h-e+a>=0 & A>a & fi!=.
					replace Fexact=Fexact+fi if a<=g & h-e+a>=0 & A>=a & fi!=.
			}		
			cap drop texact
			gen texact=Fminus1exact+(Fexact-Fminus1exact)*runiform() 
			count if texact<=0.025 | texact>=0.975
			local Npointreject05=r(N)
			count if texact<=0.05 | texact>=0.95
			local Npointreject10=r(N)
			
			*exact test
			ksmirnov texact=texact
			local Dexact=r(D)
			local pexact=r(p)
		}
post myhandle  (_N)  (`Dexact') (`pexact') (`Npointreject05') (`Npointreject10')
}

postclose myhandle
use "Results/KSexactOneil.dta", clear
gen pointreject05=Npointreject05/N*100
gen pointreject10=Npointreject10/N*100
sum N pointreject05 pointreject10

gen id=_n
egen pmean=mean(pexact)
cap drop reject05
gen reject05=0 
replace reject05=1 if pexact<=0.05
cap drop preject05
egen preject05=mean(reject05)
cap drop reject10
gen reject10=0 
replace reject10=1 if pexact<=0.1
cap drop preject10
egen preject10=mean(reject10)

sum pexact 
local min:di%4.3f r(min)
local max:di%4.3f r(max)
local mean:di%4.3f r(mean)
local Npoint=r(N)
count if pexact<=0.05 
local preject5=r(N)/`Npoint'*100
local preject5:di%4.2f `preject5'
count if pexact<=0.1
local preject10=r(N)/`Npoint'*100
local preject10:di%4.2f `preject10'
if `max'==1{
	local max:di%1.0f `max'
}
if `min'==0{
	local min:di %1.0f `min'
}
if `preject5'==100{
	local preject5:di%1.0f `preject10'
}
if `preject5'==0{
	local preject5:di %1.0f `preject10'
}
if `preject10'==100{
	local preject10:di%1.0f `preject10'
}
if `preject10'==0{
	local preject10:di %1.0f `preject10'
}
count  
local N:di%5.0fc r(N)
local line6="# iteration="+"`N'"
		
local line1="min="+"`min'"
local line2="max="+"`max'"
local line3="mean="+"`mean'"
local line4="% rejected at 5%="+"`preject5'"+" %"
local line5="% rejected at 10%="+"`preject10'"+" %"
count 
local N:di%5.0fc r(N)
local line6="# iteration="+"`N'"
local y=38.25
local x=0.28
local maxy=51
		
local maxy2=`maxy'*0.8
		
di `x'
di `y'
local namegraph="Figure\histpOneil.png"
tw (hist pexact,  w(0.01)   ///
	plotr(margin(zero)) xlabel(0 0.05 0.1 1) graphregion(color(white)) color(gs12) legend(off)  ytitle("Density", size(5)) ///
	text(`y' `x' "`line1'" "`line2'" "`line3'" "`line4'" "`line5'",  ///
	size(5) box  justification(left) bmargin(vlarge)  bcolor(white) width(40) height(15)   placement(12) )) ///
	(scatteri 0 0.05 `maxy' 0.05, lw(thin)  c(l) m(i) lcolor(black)  ) ///
	(scatteri 0 0.1 `maxy' 0.1, lw(thin)  c(l) m(i) lcolor(black) name("`source'",replace) )
graph export "`namegraph'" ,  wid(1200) hei(900) as(png) replace
				
local namegraph="Figure\histpOneilcolor.png"
tw (hist pexact,  w(0.01)   ///
	plotr(margin(zero)) xlabel(0 0.05 0.1 1) graphregion(color(white)) legend(off)  ytitle("Density", size(5)) ///
	text(`y' `x' "`line1'" "`line2'" "`line3'" "`line4'" "`line5'",  ///
	size(5) box  justification(left) bmargin(vlarge)  bcolor(white) width(40) height(15)   placement(12) )) ///
	(scatteri 0 0.05 `maxy' 0.05, lw(thin)  c(l) m(i) lcolor(black)  ) ///
	(scatteri 0 0.1 `maxy' 0.1, lw(thin)  c(l) m(i) lcolor(black) name("`source'",replace) )
graph export "`namegraph'" ,  wid(1200) hei(900) as(png) replace
