set varabbrev off
cap postclose myhandle
set more off

postfile myhandle str10 gender nserve Nexact Dexact pexact  str6 server str6  receiver using "Results\KSexactHKrank", replace
foreach gender in "male" "female"{
	di "`gender'"
	if "`gender'"=="male"{
		local median=22 /*median rank*/
	}
	if "`gender'"=="female"{
		local median=17
	}
	di `median'
	foreach server in /*"top" "nontop"*/ "all"{
		foreach receiver in "top" "nontop" "all"{
			foreach nserve in 10{
				di `nserve'
				use "./data/pointgames.dta", clear
				keep if totalserves1>=`nserve' & gender=="`gender'" & rrank!=. & srank!=.
				if "`server'"=="top"{
						keep if srank<=`median'
				}
				if "`server'"=="nontop"{
					keep if srank>`median'
				}
				if "`receiver'"=="top"{
					keep if rrank<=`median'
				}
				if "`receiver'"=="nontop"{
					keep if rrank>`median'
				}
				cap drop pointwon
				gen pointwon=pointwonL1+pointwonR1
				cap drop pointlost
				gen pointlost=totalserves1-pointwon
				gen A=pointwonL1
				gen e=pointwon
				gen f=pointlost
				gen g=servesL1
				gen h=servesR1
				gen b=0
				cap drop c
				gen c=0
				gen d=0
				gen a=0
				egen maxpointwon=max(pointwon)
				local maxpointwon=maxpointwon
				cap drop Fexact
				gen double  Fexact=0
				cap drop Fminus1exact                 
				gen double  Fminus1exact=0
				cap drop Ftotexact
				gen double  Ftotexact=0
				local maxpointwon=maxpointwon
				cap drop fi
				gen double fi=0

				forvalues a=0/`maxpointwon'{
					replace fi=0
					replace a=`a'
					replace b=e-a if a<=g & h-e+a>=0
					replace c=g-a if a<=g & h-e+a>=0
					replace d=h-b if a<=g & h-e+a>=0
					replace fi= round(exp(lnfactorial(e)),1)*round(exp(lnfactorial(f)),1)*round(exp(lnfactorial(g)),1)*round(exp(lnfactorial(h)),1) ///
						/(round(exp(lnfactorial(a)),1)*round(exp(lnfactorial(b)),1)*round(exp(lnfactorial(c)),1)*round(exp(lnfactorial(d)),1)*round(exp(lnfactorial(a+b+c+d)),1)) if a<=g & h-e+a>=0 
					replace Ftotexact=Ftotexact+fi if a<=g & h-e+a>=0 & fi!=.
					replace Fminus1exact=Fminus1exact+fi if a<=g & h-e+a>=0 & A>a & fi!=.
					replace Fexact=Fexact+fi if a<=g & h-e+a>=0 & A>=a & fi!=.
				}			
				forval j=1/10000{ /*number iteration at a specific winrate*/
					if mod(`j',100)==0	{	
						di `j'
					}
					cap{			
						cap drop texact
						gen texact=Fminus1exact+(Fexact-Fminus1exact)*runiform()
						count if texact<=0.025 | texact>=0.975
						local Npointreject05=r(N)
						count if texact<=0.05 | texact>=0.95
						local Npointreject10=r(N)
						cap drop c
						cumul texact, gen(c)
						sort c
						ksmirnov texact=texact 
						local KS=sqrt(_N)*r(D)
						local Nexact=_N
						local Dexact=r(D)
						local pexact=r(p)
					}
				post myhandle  ("`gender'") (`nserve') (`Nexact') (`Dexact') (`pexact') ("`server'") ("`receiver'")
				}
			}
		}
	}
}
postclose myhandle

use "Results\KSexactHKrank.dta", clear
sort gender nserve server receiver
gen id=_n

	by gender nserve server receiver: egen pmean=mean(pexact)
	cap drop reject5
	gen reject5=0 
	replace reject5=1 if pexact<0.05
	cap drop preject5
	by gender nserve server receiver: egen preject5=mean(reject5)
	cap drop reject10
	by gender nserve server receiver: gen reject10=0 
	 replace reject10=1 if pexact<0.1
	cap drop preject10
	by gender nserve server receiver: egen preject10`test'=mean(reject10`test')

by gender nserve server receiver: gen first=1 if _n==1 
ed if first==1 & receiver=="all"

foreach gender in "male" "female"{
	di "`gender'"
	foreach server in /*"top" "nontop"*/ "all"{
		foreach receiver in "top" "nontop" "all"{	
			sum pexact if gender=="`gender'" & nserve==10 & server=="`server'" & receiver=="`receiver'"
			local min:di%4.3f r(min)
			local max:di%4.3f r(max)
			local mean:di%4.3f r(mean)

			if `max'==1{
				local max:di%1.0f `max'
			}
			if `min'==0{
				local min:di %1.0f `min'
			}
					
			local line1="min="+"`min'"
			local line2="max="+"`max'"
			local line3="mean="+"`mean'"
			local  Npoint=r(N)
			count if   gender=="`gender'" & nserve==10 & server=="`server'" & receiver=="`receiver'"
			local N:di%5.0fc r(N)
			local line7="# iteration="+"`N'"
				
			count if pexact<=0.05 & gender=="`gender'" & nserve==10 & server=="`server'" & receiver=="`receiver'"
			local preject5=r(N)/`Npoint'*100
			local preject5:di%4.2f `preject5'
			count if pexact<=0.1 & gender=="`gender'" & nserve==10 & server=="`server'" & receiver=="`receiver'"
			local preject10=r(N)/`Npoint'*100
			local preject10:di%4.2f `preject10'
					
					
			if `preject5'==100{
				local preject5:di%1.0f `preject10'
			}
			if `preject5'==0{
				local preject5:di %1.0f `preject10'
			}
			if `preject10'==100{
				local preject10:di%1.0f `preject10'
			}
			if `preject10'==0{
				local preject10:di %1.0f `preject10'
			}
					
			local line1="min="+"`min'"
			local line2="max="+"`max'"
			local line3="mean="+"`mean'"
			local line4="% rejected at 5%="+"`preject5'"+" %"
			local line5="% rejected at 10%="+"`preject10'"+" %"
			local x=0.3
			local maxy=4
			local y=2.5
			if "`gender'"=="female" & "`server'"!="top" & "`receiver'"!="top"{
				local y=10
				local maxy=15
			}
			if "`gender'"=="female" & "`server'"=="all" & "`receiver'"!="top"{
				local y=18.75
				local maxy=30
			}
			if "`gender'"=="female" & "`server'"=="nontop" & "`receiver'"=="nontop"{
				local y=27
				local maxy=50
			}

			sum Nexact if gender=="`gender'" & nserve==10 & server=="`server'" & receiver=="`receiver'"
			local Nmean=r(mean)
			if `Nmean'<1000{
				local Nmean:di%3.0fc r(mean)
			}
			if `Nmean'>1000{
				local Nmean:di%5.0fc r(mean)
			}
			local line6="N="+"`Nmean'"
			
			local name="histp"+"`gender'"+"`server'"+"S"+"`receiver'"+"R"
			local namegraphcolor="Figure\"+"`name'"+"color"+".png"
			tw (hist pexact if  gender=="`gender'" & nserve==10 & server=="`server'" & receiver=="`receiver'", yla(, labsize(*1.5)) xla(, labsize(*1.5)) w(0.01) name("`name'",replace)  ////
				 ytitle("Density", size(7.5))  xlabel(0 0.05 0.1 1) graphregion(color(white)) legend(off) plotr(margin(zero))   ///
				text(`y' `x' "`line1'" "`line2'" "`line3'" "`line4'" "`line5'"  "`line6'", ////
				size(7.5) box  justification(left) bmargin(vlarge)  bcolor(white) width(40) height(15)   placement(12) ) )  ///
				(scatteri 0 0.05 `maxy' 0.05, lw(thin)  c(l) m(i) lcolor(black)  ) ///
				(scatteri 0 0.1 `maxy' 0.1, lw(thin)  c(l) m(i) lcolor(black) )
			graph export "`namegraphcolor'" , wid(1200) hei(900)  as(png) replace
		}
	}
}
