clear
set varabbrev off
cap postclose myhandle
set more off

local i=`:environment SLURM_ARRAY_TASK_ID' /*goes from 0 to 101*/
local seed=`i'*18901
set seed `seed'
local filename="fixed_"+"`i'"

local theta=`i'/(100)
if `i'==101{
	local theta=2/3
}

postfile myhandle theta N Dexact pexact  Dchi pchi pjointpearson Nsample using "`filename'", replace
set more off
local Nit=101
foreach Nsample in 40 7000{ /*sample size*/
	clear
	set obs `Nsample'
	gen totalserves=30
	
	gen A=0
	gen a=0
	gen b=0
	cap drop c 
	gen c=0
	gen d=0 
	gen e=0
	gen f=0
	gen g=0
	gen h=0
	forval i=1/1{
		di `i'
		di `epsilon'
		cap drop winratesL
		gen winratesL=0.58*`theta'+0.79*(1-`theta')
		cap drop winratesR
		gen winratesR=0.73*`theta'+0.49*(1-`theta')
			forval j=1/10000{ /*number iteration at a specific winrate*/
			if mod(`j',250)==0{
				di `j'
				}
			cap{
				cap drop servesL
				gen servesL=rbinomial(totalserves,1/2)  
				cap drop servesR
				gen servesR=totalserves-servesL
 
				* we use servesL servesR winrates
				cap drop nwinL
				gen nwinL=rbinomial(servesL,winratesL)
				replace nwinL=0 if servesL==0
				replace nwinL=servesL if winratesL==1
				
				* we do the same for right serve
				cap drop nwinR
				gen nwinR=rbinomial(servesR,winratesR)
				replace nwinR=0 if servesR==0
				replace nwinR=servesR if winratesR==1
				
				cap drop nwin
				gen nwin=nwinL+nwinR
				cap drop nlost
				gen nlost=totalserves-nwin

				cap drop Fexact
				gen double  Fexact=0
				cap drop Fminus1exact
				gen double  Fminus1exact=0
				cap drop Ftotexact
				gen double  Ftotexact=0
				cap drop maxpointwon
				egen maxpointwon=max(nwin)
				local maxpointwon=maxpointwon
				cap drop fi
				gen double fi=0

				replace A=nwinL
				replace e=nwin
				replace f=nlost
				replace g=servesL
				replace h=servesR
				replace b=0
				replace c=0
				replace d=0
				replace a=0
				forvalues a=0/`maxpointwon'{
					replace fi=0
					replace a=`a'
					replace b=e-a if a<=g & h-e+a>=0
					replace c=g-a if a<=g & h-e+a>=0
					replace d=h-b if a<=g & h-e+a>=0
					*local tab="`a'"+","+"`b'"+"/"+"`c'"+","+"`d'"
					replace fi= round(exp(lnfactorial(e)),1)*round(exp(lnfactorial(f)),1)*round(exp(lnfactorial(g)),1)*round(exp(lnfactorial(h)),1) ///
						/(round(exp(lnfactorial(a)),1)*round(exp(lnfactorial(b)),1)*round(exp(lnfactorial(c)),1)*round(exp(lnfactorial(d)),1)*round(exp(lnfactorial(a+b+c+d)),1)) if a<=g & h-e+a>=0 
						replace Ftotexact=Ftotexact+fi if a<=g & h-e+a>=0 & fi!=.
						replace Fminus1exact=Fminus1exact+fi if a<=g & h-e+a>=0 & A>a & fi!=.
						replace Fexact=Fexact+fi if a<=g & h-e+a>=0 & A>=a & fi!=.
					}
				
				*fisher exact test
				cap drop texact
				gen texact=Fminus1exact+(Fexact-Fminus1exact)*runiform()

				cap drop c
				cumul texact, gen(c)
				sort c
				ksmirnov texact=texact 
				local KS=sqrt(_N)*r(D)
				local Dexact=.
				local pexact=.
				local r(D)=.
				local r(p)=.
				local Dexact=r(D)
				local pexact=r(p)

				
				///////////////////
				*old test
				cap drop winratesgen
				gen winratesgen=(nwinL+nwinR)/totalserves
				
				cap drop totalpointwongen
				gen totalpointwongen=nwinR+nwinL
				cap drop pearsonstatgen
				gen pearsonstatgen=(nwinL-servesL*winratesgen)^2/(servesL*winratesgen) ////
							+((servesL-nwinL)-servesL*(1-winratesgen))^2/(servesL*(1-winratesgen)) ///
							+(nwinR-servesR*winratesgen)^2/(servesR*winratesgen) ////
							+((servesR-nwinR)-servesR*(1-winratesgen))^2/(servesR*(1-winratesgen))

									
				cap drop pvalgen
				gen pvalgen=chi2tail(1,pearsonstatgen)
				
				cap drop c        
				cumul pvalgen, gen(c)
				sort c 
				ksmirnov pvalgen=pvalgen
				local KS=sqrt(_N)*r(D)
				local Dchi=.
				local pchi=.
				local r(D)=.
				local r(p)=.
				local Dchi=r(D)
				local pchi=r(p)
				
				cap drop totpearson
				egen totpearson=total(pearsonstatgen)
				local totpearson=totpearson[1]
				cap drop pjointpearson
				count
				di totpearson
				gen pjointpearson=chi2tail(_N,totpearson)
				local pjointpearson=pjointpearson[1]
				
				post myhandle (`theta')  (_N) (`Dexact') (`pexact') (`Dchi') (`pchi') (`pjointpearson') (`Nsample')
			}
		}
	}
}
postclose myhandle

